@@ -521,7 +521,7 @@ void KopeteMetaContactLVI::slotPhotoChanged()
 		{
 			int photoSize = d->iconSize;
 
-			photoImg = photoImg.smoothScale( photoSize, photoSize, TQ_ScaleMin );
+			photoImg = photoImg.smoothScale( photoSize, photoSize, TQImage::ScaleMin );
 			
 			KImageEffect *effect = 0L;
 			switch ( m_metaContact->status() )
