@@ -968,8 +968,7 @@ void KopeteWindow::setStatusMessage( const TQString & message )
 
 void KopeteWindow::slotBuildStatusMessageMenu()
 {
-	TQObject * senderObj = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>( sender() ));
-	m_globalStatusMessageMenu = static_cast<TDEPopupMenu *>( TQT_TQWIDGET(senderObj) );
+	m_globalStatusMessageMenu = static_cast<TDEPopupMenu *>( const_cast<TQObject*>(sender()) );
 	m_globalStatusMessageMenu->clear();
 // pop up a menu containing the away messages, and a lineedit
 // see kopeteaway
@@ -985,12 +984,12 @@ void KopeteWindow::slotBuildStatusMessageMenu()
 	m_newMessageEdit->setText(Kopete::Away::message());
 
 	newMessageBox->setFocusProxy( m_newMessageEdit );
-	newMessageBox->setFocusPolicy( TQ_ClickFocus );
+	newMessageBox->setFocusPolicy( TQWidget::ClickFocus );
 /*	newMessageLabel->setFocusProxy( newMessageEdit );
 	newMessageLabel->setBuddy( newMessageEdit );
-	newMessageLabel->setFocusPolicy( TQ_ClickFocus );*/
+	newMessageLabel->setFocusPolicy( TQWidget::ClickFocus );*/
 	newMessagePix->setFocusProxy( m_newMessageEdit );
-	newMessagePix->setFocusPolicy( TQ_ClickFocus );
+	newMessagePix->setFocusPolicy( TQWidget::ClickFocus );
 	connect( m_newMessageEdit, TQT_SIGNAL( returnPressed() ), TQT_SLOT( slotNewStatusMessageEntered() ) );
 
 	m_globalStatusMessageMenu->insertItem( newMessageBox );
@@ -1111,4 +1110,3 @@ void KopeteWindow::showAddContactDialog( Kopete::Account * account )
 }
 
 #include "kopetewindow.moc"
-// vim: set noet ts=4 sts=4 sw=4:
