@@ -56,7 +56,7 @@ namespace Kopete
  */
 class KOPETE_EXPORT Away : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 friend class ::KopeteAwayDialog;
