@@ -690,7 +690,7 @@ TQImage MetaContact::photo() const
   if( picture().image().width() > 96 && picture().image().height() > 96 )
     {
       kdDebug( 14010 )  << k_funcinfo << "Resizing image from " << picture().image().width() << " x " << picture().image().height() << endl;
-      return picture().image().smoothScale(96,96,TQ_ScaleMin);
+      return picture().image().smoothScale(96,96,TQImage::ScaleMin);
     }
   else
     return picture().image();
