@@ -147,7 +147,7 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
 	mHtmlView = mHtmlPart->view();
 	mHtmlView->setMarginWidth(4);
 	mHtmlView->setMarginHeight(4);
-	mHtmlView->setFocusPolicy(TQ_NoFocus);
+	mHtmlView->setFocusPolicy(TQWidget::NoFocus);
 	mHtmlView->setSizePolicy(
 	TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
 	l->addWidget(mHtmlView);
