@@ -28,7 +28,7 @@ class motionawayPrefsUI;
  */
 class MotionAwayPreferences : public TDECModule
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	MotionAwayPreferences(TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList());
@@ -42,5 +42,3 @@ private slots:
 };
 
 #endif
-
-// vim: set noet ts=4 sts=4 sw=4:
