@@ -1,4 +1,3 @@
-// -*- Mode: c++-mode; c-basic-offset: 2; indent-tabs-mode: t; tab-width: 2; -*-
 //
 // Copyright (C) 2003 Grzegorz Jaskiewicz 	<gj at pointblue.com.pl>
 // Copyright (C) 2002-2003 Zack Rusin	<zack@kde.org>
@@ -31,7 +30,7 @@ class GaduAwayUI;
 
 class GaduAway : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
