@@ -106,11 +106,7 @@ TQ_LONG KSSLSocket::writeBlock( const char* data, TQ_ULONG len )
 	return d->kssl ? (d->kssl->write(data, len)) : -1;
 }
 
-#ifdef USE_QT4
-qint64 KSSLSocket::bytesAvailable() const
-#else // USE_QT4
 int KSSLSocket::bytesAvailable() const
-#endif // USE_QT4
 {
 	if( socketStatus() < connected )
 		return -2;
