@@ -63,7 +63,7 @@ static bool haveHost(const StreamHostList &list, const Jid &j)
 
 class S5BManager::Item : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	enum { Idle, Initiator, Target, Active };
@@ -1748,7 +1748,7 @@ void S5BManager::Item::finished()
 //----------------------------------------------------------------------------
 class S5BConnector::Item : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	SocksClient *client;
@@ -1980,7 +1980,7 @@ void S5BConnector::man_udpSuccess(const Jid &streamHost)
 //----------------------------------------------------------------------------
 class S5BServer::Item : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	SocksClient *client;
