@@ -27,7 +27,7 @@ class TQVBox;
 
 class ICQReadAway : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
@@ -50,4 +50,3 @@ class ICQReadAway : public KDialogBase
 		KTextBrowser *awayMessageBrowser;
 };
 #endif
-// vim: set noet ts=4 sts=4 sw=4:
