@@ -1127,8 +1127,7 @@ void Client::requestServerRedirect( WORD family, WORD exchange,
 void Client::haveServerForRedirect( const TQString& host, const TQByteArray& cookie, WORD )
 {
     //nasty sender() usage to get the task with chat room info
-	TQObject* o = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>( sender() ));
-    ServerRedirectTask* srt = dynamic_cast<ServerRedirectTask*>( o );
+    ServerRedirectTask* srt = dynamic_cast<ServerRedirectTask*>( const_cast<TQObject*>(sender()) );
 
 	//create a new connection and set it up
 	int colonPos = host.find(':');
@@ -1248,8 +1247,7 @@ void Client::determineDisconnection( int code, const TQString& string )
         return;
 
     //yay for the sender() hack!
-	TQObject* obj = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>( sender() ));
-    Connection* c = dynamic_cast<Connection*>( obj );
+    Connection* c = dynamic_cast<Connection*>( const_cast<TQObject*>(sender()) );
     if ( !c )
         return;
 
@@ -1352,4 +1350,3 @@ bool Client::hasIconConnection( ) const
 }
 
 #include "client.moc"
-//kate: tab-width 4; indent-mode csands; space-indent off; replace-tabs off;
