@@ -475,7 +475,7 @@ void OscarAccount::setBuddyIcon( KURL url )
 		
 		const TQSize size = ( d->engine->isIcq() ) ? TQSize( 52, 64 ) : TQSize( 48, 48 );
 		
-		image = image.smoothScale( size, TQ_ScaleMax );
+		image = image.smoothScale( size, TQImage::ScaleMax );
 		if( image.width() > size.width())
 			image = image.copy( ( image.width() - size.width() ) / 2, 0, size.width(), image.height() );
 		
