@@ -1791,7 +1791,7 @@ void YahooAccount::setBuddyIcon( const KURL &url )
 			KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry, i18n( "<qt>The selected buddy icon could not be opened. <br />Please set a new buddy icon.</qt>" ), i18n( "Yahoo Plugin" ) );
 			return;
 		}
-		image = image.smoothScale( 96, 96, TQ_ScaleMin );
+		image = image.smoothScale( 96, 96, TQImage::ScaleMin );
 		if(image.width() < image.height())
 		{
 			image = image.copy((image.width()-image.height())/2, 0, 96, 96);
