@@ -132,7 +132,7 @@ namespace KPF
             break;
           }
 
-          if (!TQT_TQRECT_OBJECT(rect()).contains(e->pos()))
+          if (!rect().contains(e->pos()))
           {
             break;
           }
