@@ -342,7 +342,13 @@ void Opener::mainLoop() {
 //
 int Opener::sendFD(int fd, struct ResponseHeader *response) {
 
-  struct { struct cmsghdr cmsg; int fd; } control;
+  union {
+    struct {
+      char _cmsg[sizeof(struct cmsghdr)];
+      char data[sizeof(int)];  // int fd field
+    };
+    struct cmsghdr cmsg;
+  } control;
   struct msghdr	msg;
   struct iovec iov;
 
