@@ -15,7 +15,7 @@
 
 class PageServChan : public PageServChanBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
