@@ -9,7 +9,7 @@ class PTabDialog;
 
 class PTabDialog : public PWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   static PObject *createWidget(CreateArgs &ca);
