@@ -14,7 +14,7 @@
 
 class ssfePrompt : public ssfepromptdata
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
