@@ -244,7 +244,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
 #endif
 
   mainw = new KSircView(ksircProcess(), pan, kstn + "KSircView" );
-  mainw->setFocusPolicy(TQ_NoFocus);
+  mainw->setFocusPolicy(TQWidget::NoFocus);
 
   nicks_box = new TQVBox(pan);
 
@@ -253,7 +253,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
            this, TQT_SLOT(setMode(TQString, int, TQString)));
 
   nicks = new aListBox(nicks_box, kstn + "aListBox");
-  nicks->setFocusPolicy(TQ_NoFocus);
+  nicks->setFocusPolicy(TQWidget::NoFocus);
   //nicks->hide(); // default = only the main widget
 
   lag = new TQLabel(nicks_box);
@@ -360,7 +360,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
 
   // setup line editor
 
-  linee->setFocusPolicy(TQ_StrongFocus);
+  linee->setFocusPolicy(TQWidget::StrongFocus);
   linee->setFont(ksopts->defaultFont);
 
   if(ksopts->oneLineEntry == true) {
@@ -1285,7 +1285,7 @@ void KSircTopLevel::control_message(int command, TQString str)
           logFile->open();
       }
       setName(m_channelInfo.server().utf8() + "_" + m_channelInfo.channel().utf8() + "_" + "toplevel");
-      pan->setName(TQCString(TQT_TQOBJECT(this)->name()) + "_" + TQSPLITTER_OBJECT_NAME_STRING);
+      pan->setName(TQCString(TQT_TQOBJECT(this)->name()) + "_" + "TQSplitter");
       kmenu->setName(TQCString(TQT_TQOBJECT(this)->name()) + "_tdetoolframe");
       linee->setName(TQCString(TQT_TQOBJECT(this)->name()) + "_" + "LineEnter");
       kmenu->show();
