@@ -37,7 +37,7 @@ class TQStringList;
  */
 class KTorrentPlugin : public KFilePlugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
